% File: DdpDt_dissterm_model1.m
% Author: Dennis G. Thomas
% Created date: December 2013
% Last modified: July 29, 2017

% Function to describe the dissolution model of silver nanoparticles
function DdpDt_term = DdpDt_dissterm_model1(diss_parms,Cf,Cp,V)

% diss_parms:  parameters associated with the dissolution of particles in
% the empirical dissolution model

%----
%  dDpdt = -2/rhop*[term1 + term2 + term3]
%  term1 = kf*(C_f,sat - Cf)
%  term2 = kp*(n*P0 - Cp)
%  term3 = kp2*(n2*P0-Cp)
%  This function only computes term1 + term2 + term3
%  DdpDt_term = term1 + term2 + term3
% Note: minus sign is not included in the sum
% ---

P0 = diss_parms.P0; % percentage of FBS in solution
kf = diss_parms.kf; % rate constant for dissolution of particles to free ions (in ml/(nm^2 hr) [diffusivity,D/distance,h]
Cfsat = diss_parms.Cfsat; % saturated concentration of free ions in the media (in ug/ml)
kp = diss_parms.kp; % rate constant for slow transfer of ions from the particle surface to the proteins (in ml/(nm^2 hr)));
kp2 = diss_parms.kp2; % rate constant for the initial fast transfer of ions from the particle surface to the proteins (in ml/(nm^2 hr))
n = diss_parms.n; % concentration of binding sites available on the proteins per FBS for the slow binding period of the ions% (in ug ml^-1 FBS%^-1)
n2 = diss_parms.n2; % concentration of binding sites available on the proteins per FBS for the fast binding period of the ions% (in ug ml^-1 FBS%^-1)

term1 = 0;
term2 =0;
term3 = 0;

if(Cf <= Cfsat)
term1 = kf*(Cfsat - Cf);
end
if(Cp<=n*P0)
term2 = kp*(n*P0 - Cp);
end
if(Cp<=n2*P0)
term3 = kp2*(n2*P0 - Cp);
end

DdpDt_term = term1 + term2 + term3;

end