% File: writeParameters.m
% Author: Dennis G. Thomas
% Created date: December 2013
% Last Modified: July 30, 2017

% Function to write out the simulation parameters to output file.
function writeParameters(parameter,diss_parameters,uptake_parms,fname)
parmlist=[];
parmlist = [parmlist;{'Parameter','Value','Unit','Description'}];
parmlist = [parmlist;{'parameter.results_matfile',parameter.results_matfile,'','.mat file where the simulation outputs are saved'}];
parmlist = [parmlist;{'parameter.use_xlwrite',parameter.use_xlwrite,'','xlwrite option'}];
parmlist = [parmlist;{'parameter.num_procs',num2str(parameter.num_procs),'','number of processors used for parallel for-loop'}];
parmlist = [parmlist;{'LIQUID MEDIA CHARACTERISTICS','','',''}];

parmlist = [parmlist;{'parameter.media_height',num2str(parameter.media_height),'m','media height'}];
parmlist = [parmlist;{'parameter.media_volume',num2str(parameter.media_volume),'mL','media volume'}];
parmlist = [parmlist;{'parameter.media_temperature',num2str(parameter.media_temperature),'K','media temperature'}];
parmlist = [parmlist;{'parameter.media_viscosity',num2str(parameter.media_viscosity),'N s/m^2','media viscosity'}];
parmlist = [parmlist;{'parameter.media_density',num2str(parameter.media_density),'g/mL','media density'}];
parmlist = [parmlist;{'parameter.media_surfacearea',num2str(parameter.media_surfacearea),'m^2','cell surface area'}];
parmlist = [parmlist;{'PRIMARY PARTICLE CHARACTERISTICS','','',''}];
parmlist= [parmlist;{'parameter.conc',num2str(parameter.conc),'ug/mL','particle concentration'}];
parmlist = [parmlist;{'parameter.ptcl_diameter',num2str(parameter.ptcl_diameter),'nm','primary particle diameter'}];
parmlist = [parmlist;{'parameter.ptcl_density',num2str(parameter.ptcl_density),'g/mL','primary particle density'}];
parmlist = [parmlist;{'INITIAL SIZE DISTRIBUTION CHARACTERISTICS','','',''}];
parmlist=[parmlist;{'parameter.size_distribution_type',parameter.size_distribution_type,'nm','type of size distribution'}];
parmlist=[parmlist;{'parameter.ptcl_avg_diameter',num2str(parameter.ptcl_avg_diameter),'nm','average diameter (normal)'}];
parmlist=[parmlist;{'parameter.ptcl_sd_diameter',num2str(parameter.ptcl_sd_diameter),'nm','standard deviation (normal)'}];
parmlist=[parmlist;{'parameter.ptcl_max_diameter',num2str(parameter.ptcl_max_diameter),'nm','maximum diameter used'}];
parmlist=[parmlist;{'parameter.ptcl_min_diameter',num2str(parameter.ptcl_min_diameter),'nm','minimum diameter used'}];
parmlist = [parmlist;{'PARTICLE PROTEIN LAYER CHARACTERISTICS','','',''}];
parmlist = [parmlist;{'parameter.ptcl_protein_thickneess',num2str(parameter.ptcl_protein_thickness),'nm','thickness of protein layer coating the surface of particles'}];
parmlist = [parmlist;{'parameter.ptcl_protein_density',num2str(parameter.ptcl_protein_density),'g/mL','density of protein-coated particles'}];

parmlist = [parmlist;{'PARTICLE AGGLOMERATE CHARACTERISTICS','','',''}];
parmlist=[parmlist;{'parameter.DF',num2str(parameter.DF),'','fractal dimension'}];
parmlist=[parmlist;{'parameter.PF',num2str(parameter.PF),'','packing factor'}];
parmlist=[parmlist;{'parameter.agg_yn',parameter.agg_yn,'','option to consider agglomerates'}];
switch(parameter.agg_yn)
    
    case 'agg_y'
        aggyn = 'YES';
    case 'agg_n'
        aggyn = 'NO';
end
parmlist=[parmlist;{'consider agglomerates',aggyn,'',''}];
parmlist = [parmlist;{'GRID SIZE AND TIME INTEGRATION PARAMETERS','','',''}];

parmlist=[parmlist;{'parameter.del_dp',num2str(parameter.del_dp),'nm','grid spacing along diameter axis'}];
parmlist=[parmlist;{'parameter.Nx',num2str(parameter.Nx),'nm','number of grid points along x axis'}];
parmlist=[parmlist;{'parameter.tmaxh',num2str(parameter.tmaxh),'h','total simulation time'}];
parmlist=[parmlist;{'parameter.Nt',num2str(parameter.Nt),'','number of time steps'}];
parmlist = [parmlist;{'BOUNDARY CONDITIONS','','',''}];
parmlist=[parmlist;{'parameter.bctype',parameter.bctype,'','boundary condition at bottom (cell) surface(x=L)'}];

parmlist = [parmlist;{'DISSOLUTION MODEL PARAMETERS','','',''}];
parmlist=[parmlist;{'diss_parameters.P0',num2str(diss_parameters.P0),'%','percentage of FBS in solution'}];
parmlist=[parmlist;{'diss_parameters.kf',num2str(diss_parameters.kf),'mL/(nm^2 h)','rate constant for dissolution of particles to free ions'}];
parmlist=[parmlist;{'diss_parameters.Cfsat',num2str(diss_parameters.Cfsat),'ug/mL','saturated concentration of free ions in the media'}];
parmlist=[parmlist;{'diss_parameters.kp',num2str(diss_parameters.kp),'mL/(nm^2 h)','rate constant for slow transfer of ions from the particle surface to the proteins'}];
parmlist=[parmlist;{'diss_parameters.kp2',num2str(diss_parameters.kp2),'mL/(nm^2 h)','rate constant for the initial fast transfer of ions from the particle surface to the proteins'}];
parmlist=[parmlist;{'diss_parameters.kfp',num2str(diss_parameters.kfp),'mL/(ug h)','rate constant for the transfer of free ions from solution to the proteins'}];
parmlist=[parmlist;{'diss_parameters.kp2f',num2str(diss_parameters.kp2f),'mL/(ug h)','rate constant for the transfer of ions from the protein-bound state to the free ion state'}];
parmlist=[parmlist;{'diss_parameters.n',num2str(diss_parameters.n),'ug /(mL FBS%)','concentration of binding sites available on the proteins per FBS for the slow binding period of the ions'}];
parmlist=[parmlist;{'diss_parameters.n2',num2str(diss_parameters.n2),'ug /(mL FBS%)','concentration of binding sites available on the proteins per FBS for the fast binding period of the ions'}];

parmlist = [parmlist;{'ION CELLULAR UPTAKE MODEL PARAMETERS','','',''}];
parmlist=[parmlist;{'uptake_parms.sa2',num2str(uptake_parms.sa2),'cm2',''}];
parmlist=[parmlist;{'uptake_parms.dis2',num2str(uptake_parms.dis2),'cm',''}];
parmlist=[parmlist;{'uptake_parms.d12',num2str(uptake_parms.d12),'cm2/h',''}];
parmlist=[parmlist;{'uptake_parms.pc21',num2str(uptake_parms.pc21),'',''}];
parmlist=[parmlist;{'uptake_parms.cellv',num2str(uptake_parms.cellv),'mL','cell volume'}];

if(strcmp(parameter.use_xlwrite,'yes')==1)
xlwrite([fname,'.xlsx'],parmlist,'parameters');
else
    xlswrite([fname,'.xlsx'],parmlist,'parameters');
end

%parmfile = [fname,'_parameters.txt'];

%fid = fopen(parmfile, 'w');
%i = 1;
%   fprintf(fid, '%s, %s, %s, %s\n', parmlist{i,1},parmlist{i,2},parmlist{i,3},parmlist{i,4});
%for i=2:length(parmlist(:,1))
%    fprintf(fid, '%s, %s, %s, %s\n', parmlist{i,1},parmlist{i,2},parmlist{i,3},parmlist{i,4});
%end
%fclose(fid);


end